'use strict';

exports.__esModule = true;
exports.default = undefined;

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _aphrodite = require('aphrodite');

var _arrayMove = require('array-move');

var _arrayMove2 = _interopRequireDefault(_arrayMove);

var _DropZoneHero = require('./components/DropZoneHero');

var _DropZoneHero2 = _interopRequireDefault(_DropZoneHero);

var _SortableList = require('./components/SortableList');

var _SortableList2 = _interopRequireDefault(_SortableList);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

//NPM


//Component


var DragNDrop = function (_Component) {
  _inherits(DragNDrop, _Component);

  function DragNDrop(props) {
    _classCallCheck(this, DragNDrop);

    var _this = _possibleConstructorReturn(this, _Component.call(this, props));

    _this.handleDrop = function (e) {
      e.preventDefault(); //prevents image from loading on the page
      var files = e.dataTransfer.files;
      _this.appendFile(files);
    };

    _this.appendFile = function (fileList) {
      var cache = _extends({}, _this.state.cache),
          newImages = [],
          files = Object.values(fileList);

      var imagePushed = false;
      if (_this.props.noCache) {
        for (var i = 0; i < files.length; i++) {
          newImages.push(files[i]);
        }
        imagePushed = true;
      } else {
        for (var i = 0; i < files.length; i++) {
          var file = files[i];
          var uid = file.name + file.lastModified;
          if (!cache[uid]) {
            cache[uid] = true;
            newImages.push(file);
            imagePushed = true;
          } else {
            _this.props.cacheCallback && _this.props.cacheCallback();
          }
        }
      }

      if (imagePushed) {
        _this.props.imageAddedCallback && _this.props.imageAddedCallback(files);
      }

      _this.setState({ cache: cache });
    };

    _this.saveBlob = function (_ref) {
      var uid = _ref.uid,
          blob = _ref.blob;

      var blobs = _extends({}, _this.state.blobs);
      blobs[uid] = blob;
      _this.setState({
        blobs: blobs
      });
    };

    _this.removeFile = function (index, uid) {
      var cache = _extends({}, _this.state.cache);
      cache[uid] = false;
      _this.props.removeImageCallback && _this.props.removeImageCallback(index);
      _this.setState({ cache: cache });
    };

    _this.onSortEnd = function (_ref2) {
      var oldIndex = _ref2.oldIndex,
          newIndex = _ref2.newIndex;

      var images = [].concat(_this.props.images);
      images = (0, _arrayMove2.default)(images, oldIndex, newIndex);
      _this.props.onSortEnd && _this.props.onSortEnd(images);
    };

    _this.state = {
      submitted: false,
      cache: {},
      blobs: {}
    };
    return _this;
  }

  DragNDrop.prototype.componentDidUpdate = function componentDidUpdate(prevProps) {
    if (prevProps !== this.props) {
      if (this.props.images && this.props.images.length === 0) {
        this.setState({ cache: {} });
      }
    }
  };

  /**
   * Handles localized image drops, function passed to children
   * @param { Event } e -- event triggered from onDrop on children
   */


  /**
   * Checks to see if image added by user already exists.
   * If image already exists, nothing will change
   * If image doesn't exists, it will add the image's uid to the cache and add the image
   * @param { Array } fileList -- array that contains image object
   */


  /**
   * Saves the blob to the state so we can access it later
   * @param { Object } uid -- the UID of the blob we want to save
   * @param { Object } blob -- the blob we wish to save to state
   */


  /**
   * Removes the images and removes the image's uid from the cache
   * @param { String } index -- the index of the image we want to remove
   */


  /**
   * Needed to allow react-sortable-hoc's dragndrop feature to work
   */


  DragNDrop.prototype.render = function render() {
    var images = this.props.images;


    return _react2.default.createElement(
      'div',
      { className: (0, _aphrodite.css)(styles.Body) },
      _react2.default.createElement(
        'div',
        { className: (0, _aphrodite.css)(styles.DropzoneContainer) },
        images.length > 0 ? _react2.default.createElement(_SortableList2.default, {
          images: images,
          axis: "xy",
          blobs: this.state.blobs,
          saveBlob: this.saveBlob,
          imageClassName: this.props.imageClassName,
          imageContainerClassName: this.props.imageContainerClassName,
          appendFile: this.appendFile,
          removeFile: this.removeFile,
          onSortEnd: this.onSortEnd,
          handleDrop: this.handleDrop,
          addImageClassName: this.props.addImageClassName,
          addImageText: this.props.addImageText,
          fileAccept: this.props.fileAccept
        }) : _react2.default.createElement(_DropZoneHero2.default, {
          images: images,
          id: 0,
          addImageClassName: this.props.addImageClassName,
          blobs: this.state.blobs,
          saveBlob: this.saveBlob,
          appendFile: this.appendFile,
          removeFile: this.removeFile,
          onSortEnd: this.onSortEnd,
          handleDrop: this.handleDrop,
          fileAccept: this.props.fileAccept,
          addImageText: this.props.addImageText
        })
      )
    );
  };

  return DragNDrop;
}(_react.Component);

exports.default = DragNDrop;


var styles = _aphrodite.StyleSheet.create({
  Body: {
    display: "flex",
    flexDirection: "column",
    justifyContent: "center",
    alignItems: "center",
    width: "100%"
  },
  DropzoneContainer: {
    display: "flex",
    flexDirection: "row",
    width: '100%',
    height: '100%',
    flexWrap: "wrap",
    margin: "0",
    overflow: "hidden",
    "::-webkit-scrollbar": {
      display: "none"
    }
  },
  DropzoneButtons: {
    display: "flex",
    flexDirection: "column",
    height: "100%",
    justifyContent: "space-between",
    alignItems: "center",
    borderLeft: "1px solid rgba(129,148,167,0.39)"
  },
  button: {
    cursor: "pointer",
    width: "80%",
    padding: "5px 0px 5px",
    color: "white",
    border: "1px solid #4285f4",
    boxShadow: 'rgba(129,148,167,0.39) 0px 3px 10px 0px',
    backgroundColor: "#4285f4",
    userSelect: "none"
  }
});
module.exports = exports['default'];